==> remorphed-fabric-1.19.4-3.1-sources.jar: tocraft/remorphed/screen/widget/PlayerWidget.java <==
package tocraft.remorphed.screen.widget;

import com.mojang.blaze3d.systems.RenderSystem;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_4264;
import net.minecraft.class_4587;
import net.minecraft.class_6382;
import net.minecraft.class_7919;
import tocraft.remorphed.screen.RemorphedScreen;
import tocraft.walkers.impl.PlayerDataProvider;
import tocraft.walkers.network.impl.SwapPackets;

@Environment(EnvType.CLIENT)
public class PlayerWidget extends class_4264 {
    private final RemorphedScreen parent;

    public PlayerWidget(int x, int y, int width, int height, RemorphedScreen parent) {
        super(x, y, width, height, class_2561.method_30163(""));
        this.parent = parent;
        method_47400(class_7919.method_47407(class_2561.method_43471("remorphed.player_icon")));
    }

    @Override
    public void method_48579(class_4587 guiGraphics, int mouseX, int mouseY, float delta) {
        if (class_310.method_1551().field_1724 != null) {
            class_2960 skinLocation = class_310.method_1551().field_1724.method_3117();
            RenderSystem.setShaderTexture(0, skinLocation);
            class_332.method_25293(guiGraphics, method_46426(), method_46427(), method_25368(), method_25364(), 8.0f, 8, 8, 8, 64, 64);
            class_332.method_25293(guiGraphics, method_46426(), method_46427(), method_25368(), method_25364(), 40.0f, 8, 8, 8, 64, 64);
        } else
            super.method_48579(guiGraphics, mouseX, mouseY, delta);
    }

    @Override
    public void method_25306() {
        if (class_310.method_1551().field_1724 != null && ((PlayerDataProvider) class_310.method_1551().field_1724).walkers$getCurrentShape() != null) {
            SwapPackets.sendSwapRequest();
            parent.method_25419();
        }
    }

    @Override
    public void method_47399(class_6382 builder) {

    }
}

==> remorphed-fabric-1.20.1-3.2-sources.jar: tocraft/remorphed/screen/widget/PlayerWidget.java <==
package tocraft.remorphed.screen.widget;

import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_4264;
import net.minecraft.class_6382;
import net.minecraft.class_7919;
import tocraft.remorphed.screen.RemorphedScreen;
import tocraft.walkers.impl.PlayerDataProvider;
import tocraft.walkers.network.impl.SwapPackets;

@Environment(EnvType.CLIENT)
public class PlayerWidget extends class_4264 {
    private final RemorphedScreen parent;

    public PlayerWidget(int x, int y, int width, int height, RemorphedScreen parent) {
        super(x, y, width, height, class_2561.method_30163(""));
        this.parent = parent;
        method_47400(class_7919.method_47407(class_2561.method_43471("remorphed.player_icon")));
    }

    @Override
    public void method_48579(class_332 guiGraphics, int mouseX, int mouseY, float delta) {
        if (class_310.method_1551().field_1724 != null) {
            class_2960 skinLocation = class_310.method_1551().field_1724.method_3117();
            guiGraphics.method_25293(skinLocation, method_46426(), method_46427(), method_25368(), method_25364(), 8.0f, 8, 8, 8, 64, 64);
            guiGraphics.method_25293(skinLocation, method_46426(), method_46427(), method_25368(), method_25364(), 40.0f, 8, 8, 8, 64, 64);
        } else
            super.method_48579(guiGraphics, mouseX, mouseY, delta);
    }

    @Override
    public void method_25306() {
        if (class_310.method_1551().field_1724 != null && ((PlayerDataProvider) class_310.method_1551().field_1724).walkers$getCurrentShape() != null) {
            SwapPackets.sendSwapRequest();
            parent.method_25419();
        }
    }

    @Override
    public void method_47399(class_6382 builder) {

    }
}
